define(function(require){
	var $ = require("jquery");
	var justep = require("$UI/system/lib/justep");
	var biz = require('$UI/system/lib/biz');
	
	var Model = function(){
		this.callParent();
		this.initOK = justep.Bind.observable(false);
		this.readonly = justep.Bind.observable(true);
		this.isReadonly = justep.Bind.computed(function() {
			if (!this.initOK.get()) {
				return false;
			}
			return this.readonly.get();
		}, this);
	};

	// 接收参数
	Model.prototype.modelParamsReceive = function(event){
		if(!(event.data)) {
			return ;
		}
		var task = event.data.task;
		var sData1 = event.data.sData1;
		var _pagePattern = event.data._pagePattern;
		this.readonly.set(_pagePattern == "readonly");
		
		var mainData = this.comp("mainData");
		if(task && sData1) {
			mainData.setFilter("filter", "ZH_WorkTicket='" + sData1 + "'");
			mainData.refreshData();
			
			var process = this.comp("process1");
			process.set({task : task});
		}
		
		// 只读模式，不验证
		if(!this.readonly.get()) {
			mainData.isValid(true);
		}
		
		this.initOK.set(true);
	};
	
	// 选择场站
	Model.prototype.button1Click = function(event){
		this.comp("stationDialog").open({
			data : {
				code : ["wind"], 
				rootFilter : '-1',
				rootFilterStr : "SA_OPOrg.sOrgKindID='wind'"
			}
		});
	};

	// 选择工单
	Model.prototype.button2Click = function(event){
		this.comp("workOrderDialog").open({data : {state : "5"}});
	};
	
	// 选择工作负责人
	Model.prototype.button3Click = function(event){
		this.comp("workLeaderDialog").open({data : {code : "psm"}});
	};
	
	// 选择班组
	Model.prototype.button4Click = function(event){
		this.comp("groupDialog").open({});
	};
	
	// 保存
	Model.prototype.toSaveMainData = function(event){
		var mainData = this.comp("mainData");
		var isValid = mainData.isValid(true);
		if(!isValid) {
			var invalidInfo = mainData.getInvalidInfo(true);
			return {isValid : isValid, invalidInfo : invalidInfo};
		} else {
			mainData.saveData();
			return isValid;
		}
	};
	
	// 去掉透明div覆盖class
	Model.prototype.clearOverlay = function(event){
		$("#x-default-overlay").removeClass("x-default-overlay-open");
	};
	
	// 选择工作人员
	Model.prototype.button5Click = function(event){
		this.comp("multiOrgDialog").open({data : {code : "psm"}});
	};

	// 选择位置
	Model.prototype.button7Click = function(event){
		this.comp("locDialog").open({data : {code : "psm"}});
	};

	Model.prototype.button9Click = function(event){
		this.comp("mainData").setValue("workers", "");
		this.comp("mainData").setValue("workersID", "");
		this.comp("mainData").setValue("workersCount", "");
	};

	Model.prototype.multiOrgDialogReceive = function(event){};

	// 选择位置之后，级联设置设备的值
	Model.prototype.locDialogReceived = function(event){
		var data = event.data;
		var ZH_EquipmentLocation = data.val('ZH_EquipmentLocation');
		var doubleCode = event.data.val("doubleCode");
		
		var options={};
		var params = new biz.Request.ActionParam();
		params.setString("id", ZH_EquipmentLocation);
		options.context = this.getContext();
		options.action = "getDeviceByLocID";
		options.parameters = params;
		try{
			var table = biz.Request.sendBizRequest(options);
			var rows = table.responseJSON.data.value.rows;
			var mainData = this.comp("mainData");
			if(1 == rows.length) {
				var equipmentName = rows[0]['equipmentName'].value;
				var workPlace = equipmentName;
				if(doubleCode && doubleCode !== "") {
					workPlace += "(" + doubleCode + ")";
				}
				mainData.setValue("workPlace", workPlace);
				
			} else {
				mainData.setValue("workPlace", "");
			}
		}catch(e){
			justep.Util.hint("查询出错，稍后重试");
		}
	};
	
	// data变化 设置父页面保存按钮
	Model.prototype.mainDataDataChange = function(event){
		if("valueChanged" == event.type) {
			this.getParentModel().comp("saveBtn").set({disabled : false});
		}
	};
	
	// data值变化
	Model.prototype.mainDataValueChange = function(event){
		if(event.col == "workers") {
			var count = 0;
			if(event.newValue && event.newValue !== "") {
				count = (event.newValue + "").split(",").length;
			}
			
			if(event.source.getValue("workLeader") && event.source.getValue("workLeader") !== "") {
				count += 1;
			}
	
			event.source.setValue("workersCount", count);
		}
	};
	
	// 选择工单：根据位置ID查询工作地点
	Model.prototype.workOrderDialogReceived = function(event){
		var data = event.data;
		var locationID = data.val('locationID');
		
		var options={};
		var params = new biz.Request.ActionParam();
		params.setString("id", locationID);
		options.context = this.getContext();
		options.action = "getAddressByLocID";
		options.parameters = params;
		try{
			var table = biz.Request.sendBizRequest(options);
			var rows = table.responseJSON.data.value.rows;
			var mainData = this.comp("mainData");
			if(1 == rows.length) {
				var equipmentName = rows[0]['equipmentName'].value;
				var doubleCode = rows[0]['doubleCode'].value;
				var workPlace = equipmentName;
				if(doubleCode && doubleCode !== "") {
					workPlace += "(" + doubleCode + ")";
				}
				mainData.setValue("workPlace", workPlace);
				
			} else {
				mainData.setValue("workPlace", "");
			}
		}catch(e){
			justep.Util.hint("查询出错，稍后重试");
		}
	};
	
	// 获取state的name
	Model.prototype.getCodeName = function(xid, code){ 
		var pmodel = this.getParentModel();
		if(!pmodel) {
			return code;
		} 
		var data = pmodel.comp(xid);
		var name = code;
		data.each(function(p){
			var row = p.row;
			if(code && (row.val("code") == code)) {
				name = row.val("name");
				p.cancel = true;
			}
		});
		return name;
	};
	
	Model.prototype.modelLoad = function(event){
		var pmodel = this.getParentModel();
		if (pmodel) {
			// 父窗口回调：注册label-title点击事件
			pmodel.afterModelLoad(this);
			
			// 根据当前流程隐藏部分inbox
			$(".inbox:eq(0)").find(".label-title").parent().siblings().hide(2000);
		}
	};
	
	return Model;
});